@@ -1,7 +1,5 @@
 <?php
 /**
- *
- *
  * CakePHP(tm) : Rapid Development Framework (http://cakephp.org)
  * Copyright (c) Cake Software Foundation, Inc. (http://cakefoundation.org)
  *
@@ -50,6 +48,19 @@ class Validation {
  */
 	public static $errors = array();
 
+/**
+ * Backwards compatibility wrapper for Validation::notBlank().
+ *
+ * @param string|array $check Value to check.
+ * @return bool Success.
+ * @deprecated 2.7.0 Use Validation::notBlank() instead.
+ * @see Validation::notBlank()
+ */
+	public static function notEmpty($check) {
+		trigger_error('Validation::notEmpty() is deprecated. Use Validation::notBlank() instead.', E_USER_DEPRECATED);
+		return static::notBlank($check);
+	}
+
 /**
  * Checks that a string contains something other than whitespace
  *
@@ -59,17 +70,16 @@ class Validation {
  * array('check' => 'valueToCheck');
  *
  * @param string|array $check Value to check
- * @return boolean Success
+ * @return bool Success
  */
-	public static function notEmpty($check) {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
-		}
-
-		if (empty($check) && $check != '0') {
+	public static function notBlank($check) {
+		if (!is_scalar($check)) {
 			return false;
 		}
-		return self::_check($check, '/[^\s]+/m');
+		if (empty($check) && (string)$check !== '0') {
+			return false;
+		}
+		return static::_check($check, '/[^\s]+/m');
 	}
 
 /**
@@ -81,17 +91,13 @@ class Validation {
  * array('check' => 'valueToCheck');
  *
  * @param string|array $check Value to check
- * @return boolean Success
+ * @return bool Success
  */
 	public static function alphaNumeric($check) {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
-		}
-
 		if (empty($check) && $check != '0') {
 			return false;
 		}
-		return self::_check($check, '/^[\p{Ll}\p{Lm}\p{Lo}\p{Lt}\p{Lu}\p{Nd}]+$/Du');
+		return static::_check($check, '/^[\p{Ll}\p{Lm}\p{Lo}\p{Lt}\p{Lu}\p{Nd}]+$/Du');
 	}
 
 /**
@@ -100,15 +106,29 @@ class Validation {
  * Returns true is string matches value min, max, or between min and max,
  *
  * @param string $check Value to check for length
- * @param integer $min Minimum value in range (inclusive)
- * @param integer $max Maximum value in range (inclusive)
- * @return boolean Success
+ * @param int $min Minimum value in range (inclusive)
+ * @param int $max Maximum value in range (inclusive)
+ * @return bool Success
  */
-	public static function between($check, $min, $max) {
+	public static function lengthBetween($check, $min, $max) {
 		$length = mb_strlen($check);
 		return ($length >= $min && $length <= $max);
 	}
 
+/**
+ * Alias of Validator::lengthBetween() for backwards compatibility.
+ *
+ * @param string $check Value to check for length
+ * @param int $min Minimum value in range (inclusive)
+ * @param int $max Maximum value in range (inclusive)
+ * @return bool Success
+ * @see Validator::lengthBetween()
+ * @deprecated Deprecated 2.6. Use Validator::lengthBetween() instead.
+ */
+	public static function between($check, $min, $max) {
+		return static::lengthBetween($check, $min, $max);
+	}
+
 /**
  * Returns true if field is left blank -OR- only whitespace characters are present in its value
  * Whitespace characters include Space, Tab, Carriage Return, Newline
@@ -117,13 +137,10 @@ class Validation {
  * array('check' => 'valueToCheck');
  *
  * @param string|array $check Value to check
- * @return boolean Success
+ * @return bool Success
  */
 	public static function blank($check) {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
-		}
-		return !self::_check($check, '/[^\\s]/');
+		return !static::_check($check, '/[^\\s]/');
 	}
 
 /**
@@ -131,17 +148,18 @@ class Validation {
  * Returns true if $check is in the proper credit card format.
  *
  * @param string|array $check credit card number to validate
- * @param string|array $type 'all' may be passed as a sting, defaults to fast which checks format of most major credit cards
+ * @param string|array $type 'all' may be passed as a sting, defaults to fast which checks format of most major credit
+ * cards
  *    if an array is used only the values of the array are checked.
  *    Example: array('amex', 'bankcard', 'maestro')
- * @param boolean $deep set to true this will check the Luhn algorithm of the credit card.
+ * @param bool $deep set to true this will check the Luhn algorithm of the credit card.
  * @param string $regex A custom regex can also be passed, this will be used instead of the defined regex values
- * @return boolean Success
+ * @return bool Success
  * @see Validation::luhn()
  */
 	public static function cc($check, $type = 'fast', $deep = false, $regex = null) {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
+		if (!is_scalar($check)) {
+			return false;
 		}
 
 		$check = str_replace(array('-', ' '), '', $check);
@@ -150,8 +168,8 @@ class Validation {
 		}
 
 		if ($regex !== null) {
-			if (self::_check($check, $regex)) {
-				return self::luhn($check, $deep);
+			if (static::_check($check, $regex)) {
+				return static::luhn($check, $deep);
 			}
 		}
 		$cards = array(
@@ -166,34 +184,36 @@ class Validation {
 				'maestro'	=> '/^(?:5020|6\\d{3})\\d{12}$/',
 				'mc'		=> '/^5[1-5]\\d{14}$/',
 				'solo'		=> '/^(6334[5-9][0-9]|6767[0-9]{2})\\d{10}(\\d{2,3})?$/',
-				'switch'	=> '/^(?:49(03(0[2-9]|3[5-9])|11(0[1-2]|7[4-9]|8[1-2])|36[0-9]{2})\\d{10}(\\d{2,3})?)|(?:564182\\d{10}(\\d{2,3})?)|(6(3(33[0-4][0-9])|759[0-9]{2})\\d{10}(\\d{2,3})?)$/',
+				'switch'	=>
+				'/^(?:49(03(0[2-9]|3[5-9])|11(0[1-2]|7[4-9]|8[1-2])|36[0-9]{2})\\d{10}(\\d{2,3})?)|(?:564182\\d{10}(\\d{2,3})?)|(6(3(33[0-4][0-9])|759[0-9]{2})\\d{10}(\\d{2,3})?)$/',
 				'visa'		=> '/^4\\d{12}(\\d{3})?$/',
 				'voyager'	=> '/^8699[0-9]{11}$/'
 			),
-			'fast' => '/^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6011[0-9]{12}|3(?:0[0-5]|[68][0-9])[0-9]{11}|3[47][0-9]{13})$/'
+			'fast' =>
+			'/^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6011[0-9]{12}|3(?:0[0-5]|[68][0-9])[0-9]{11}|3[47][0-9]{13})$/'
 		);
 
 		if (is_array($type)) {
 			foreach ($type as $value) {
 				$regex = $cards['all'][strtolower($value)];
 
-				if (self::_check($check, $regex)) {
-					return self::luhn($check, $deep);
+				if (static::_check($check, $regex)) {
+					return static::luhn($check, $deep);
 				}
 			}
 		} elseif ($type === 'all') {
 			foreach ($cards['all'] as $value) {
 				$regex = $value;
 
-				if (self::_check($check, $regex)) {
-					return self::luhn($check, $deep);
+				if (static::_check($check, $regex)) {
+					return static::luhn($check, $deep);
 				}
 			}
 		} else {
 			$regex = $cards['fast'];
 
-			if (self::_check($check, $regex)) {
-				return self::luhn($check, $deep);
+			if (static::_check($check, $regex)) {
+				return static::luhn($check, $deep);
 			}
 		}
 		return false;
@@ -207,12 +227,12 @@ class Validation {
  * @param string $operator Can be either a word or operand
  *    is greater >, is less <, greater or equal >=
  *    less or equal <=, is less <, equal to ==, not equal !=
- * @param integer $check2 only needed if $check1 is a string
- * @return boolean Success
+ * @param int $check2 only needed if $check1 is a string
+ * @return bool Success
  */
 	public static function comparison($check1, $operator = null, $check2 = null) {
-		if (is_array($check1)) {
-			extract($check1, EXTR_OVERWRITE);
+		if ((float)$check1 != $check1) {
+			return false;
 		}
 		$operator = str_replace(array(' ', "\t", "\n", "\r", "\0", "\x0B"), '', strtolower($operator));
 
@@ -254,7 +274,7 @@ class Validation {
 				}
 				break;
 			default:
-				self::$errors[] = __d('cake_dev', 'You must define the $operator parameter for %s', 'Validation::comparison()');
+				static::$errors[] = __d('cake_dev', 'You must define the $operator parameter for %s', 'Validation::comparison()');
 		}
 		return false;
 	}
@@ -265,22 +285,24 @@ class Validation {
  * @param string|array $check When used as a string, $regex must also be a valid regular expression.
  *    As and array: array('check' => value, 'regex' => 'valid regular expression')
  * @param string $regex If $check is passed as a string, $regex must also be set to valid regular expression
- * @return boolean Success
+ * @return bool Success
  */
 	public static function custom($check, $regex = null) {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
-		}
-		if ($regex === null) {
-			self::$errors[] = __d('cake_dev', 'You must define a regular expression for %s', 'Validation::custom()');
+		if (!is_scalar($check)) {
 			return false;
 		}
-		return self::_check($check, $regex);
+		if ($regex === null) {
+			static::$errors[] = __d('cake_dev', 'You must define a regular expression for %s', 'Validation::custom()');
+			return false;
+		}
+		return static::_check($check, $regex);
 	}
 
 /**
  * Date validation, determines if the string passed is a valid date.
- * keys that expect full month, day and year will validate leap years
+ * keys that expect full month, day and year will validate leap years.
+ *
+ * Years are valid from 1800 to 2999.
  *
  * ### Formats:
  *
@@ -298,15 +320,15 @@ class Validation {
  * @param string|array $format Use a string or an array of the keys above.
  *    Arrays should be passed as array('dmy', 'mdy', etc)
  * @param string $regex If a custom regular expression is used this is the only validation that will occur.
- * @return boolean Success
+ * @return bool Success
  */
 	public static function date($check, $format = 'ymd', $regex = null) {
 		if ($regex !== null) {
-			return self::_check($check, $regex);
+			return static::_check($check, $regex);
 		}
 		$month = '(0[123456789]|10|11|12)';
 		$separator = '([- /.])';
-		$fourDigitYear = '(([1][9][0-9][0-9])|([2][0-9][0-9][0-9]))';
+		$fourDigitYear = '(([1][8-9][0-9][0-9])|([2][0-9][0-9][0-9]))';
 		$twoDigitYear = '([0-9]{2})';
 		$year = '(?:' . $fourDigitYear . '|' . $twoDigitYear . ')';
 
@@ -336,7 +358,7 @@ class Validation {
 
 		$format = (is_array($format)) ? array_values($format) : array($format);
 		foreach ($format as $key) {
-			if (self::_check($check, $regex[$key]) === true) {
+			if (static::_check($check, $regex[$key]) === true) {
 				return true;
 			}
 		}
@@ -351,7 +373,7 @@ class Validation {
  * @param string $check Value to check
  * @param string|array $dateFormat Format of the date part. See Validation::date for more information.
  * @param string $regex Regex for the date part. If a custom regular expression is used this is the only validation that will occur.
- * @return boolean True if the value is valid, false otherwise
+ * @return bool True if the value is valid, false otherwise
  * @see Validation::date
  * @see Validation::time
  */
@@ -361,7 +383,7 @@ class Validation {
 		if (!empty($parts) && count($parts) > 1) {
 			$time = array_pop($parts);
 			$date = implode(' ', $parts);
-			$valid = self::date($date, $dateFormat, $regex) && self::time($time);
+			$valid = static::date($date, $dateFormat, $regex) && static::time($time);
 		}
 		return $valid;
 	}
@@ -372,17 +394,17 @@ class Validation {
  * Does not allow/validate seconds.
  *
  * @param string $check a valid time string
- * @return boolean Success
+ * @return bool Success
  */
 	public static function time($check) {
-		return self::_check($check, '%^((0?[1-9]|1[012])(:[0-5]\d){0,2} ?([AP]M|[ap]m))$|^([01]\d|2[0-3])(:[0-5]\d){0,2}$%');
+		return static::_check($check, '%^((0?[1-9]|1[012])(:[0-5]\d){0,2} ?([AP]M|[ap]m))$|^([01]\d|2[0-3])(:[0-5]\d){0,2}$%');
 	}
 
 /**
  * Boolean validation, determines if value passed is a boolean integer or true/false.
  *
  * @param string $check a valid boolean
- * @return boolean Success
+ * @return bool Success
  */
 	public static function boolean($check) {
 		$booleanList = array(0, 1, '0', '1', true, false);
@@ -398,10 +420,10 @@ class Validation {
  * - true => Any number of decimal places greater than 0, or a float|double. The '.' is required.
  * - 1..N => Exactly that many number of decimal places. The '.' is required.
  *
- * @param float $check The value the test for decimal
- * @param integer $places
+ * @param float $check The value the test for decimal.
+ * @param int $places Decimal places.
  * @param string $regex If a custom regular expression is used, this is the only validation that will occur.
- * @return boolean Success
+ * @return bool Success
  */
 	public static function decimal($check, $places = null, $regex = null) {
 		if ($regex === null) {
@@ -431,34 +453,30 @@ class Validation {
 		$check = str_replace($data['thousands_sep'], '', $check);
 		$check = str_replace($data['decimal_point'], '.', $check);
 
-		return self::_check($check, $regex);
+		return static::_check($check, $regex);
 	}
 
 /**
  * Validates for an email address.
  *
  * Only uses getmxrr() checking for deep validation if PHP 5.3.0+ is used, or
- * any PHP version on a non-windows distribution
+ * any PHP version on a non-Windows distribution
  *
  * @param string $check Value to check
- * @param boolean $deep Perform a deeper validation (if true), by also checking availability of host
+ * @param bool $deep Perform a deeper validation (if true), by also checking availability of host
  * @param string $regex Regex to use (if none it will use built in regex)
- * @return boolean Success
+ * @return bool Success
  */
 	public static function email($check, $deep = false, $regex = null) {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
-		}
-
 		if ($regex === null) {
-			$regex = '/^[\p{L}0-9!#$%&\'*+\/=?^_`{|}~-]+(?:\.[\p{L}0-9!#$%&\'*+\/=?^_`{|}~-]+)*@' . self::$_pattern['hostname'] . '$/ui';
+			$regex = '/^[\p{L}0-9!#$%&\'*+\/=?^_`{|}~-]+(?:\.[\p{L}0-9!#$%&\'*+\/=?^_`{|}~-]+)*@' . static::$_pattern['hostname'] . '$/ui';
 		}
-		$return = self::_check($check, $regex);
+		$return = static::_check($check, $regex);
 		if ($deep === false || $deep === null) {
 			return $return;
 		}
 
-		if ($return === true && preg_match('/@(' . self::$_pattern['hostname'] . ')$/i', $check, $regs)) {
+		if ($return === true && preg_match('/@(' . static::$_pattern['hostname'] . ')$/i', $check, $regs)) {
 			if (function_exists('getmxrr') && getmxrr($regs[1], $mxhosts)) {
 				return true;
 			}
@@ -475,7 +493,7 @@ class Validation {
  *
  * @param mixed $check Value to check
  * @param mixed $comparedTo Value to compare
- * @return boolean Success
+ * @return bool Success
  */
 	public static function equalTo($check, $comparedTo) {
 		return ($check === $comparedTo);
@@ -486,11 +504,11 @@ class Validation {
  *
  * @param string|array $check Value to check
  * @param array $extensions file extensions to allow. By default extensions are 'gif', 'jpeg', 'png', 'jpg'
- * @return boolean Success
+ * @return bool Success
  */
 	public static function extension($check, $extensions = array('gif', 'jpeg', 'png', 'jpg')) {
 		if (is_array($check)) {
-			return self::extension(array_shift($check), $extensions);
+			return static::extension(array_shift($check), $extensions);
 		}
 		$extension = strtolower(pathinfo($check, PATHINFO_EXTENSION));
 		foreach ($extensions as $value) {
@@ -506,7 +524,7 @@ class Validation {
  *
  * @param string $check The string to test.
  * @param string $type The IP Protocol version to validate against
- * @return boolean Success
+ * @return bool Success
  */
 	public static function ip($check, $type = 'both') {
 		$type = strtolower($type);
@@ -524,8 +542,8 @@ class Validation {
  * Checks whether the length of a string is greater or equal to a minimal length.
  *
  * @param string $check The string to test
- * @param integer $min The minimal string length
- * @return boolean Success
+ * @param int $min The minimal string length
+ * @return bool Success
  */
 	public static function minLength($check, $min) {
 		return mb_strlen($check) >= $min;
@@ -535,8 +553,8 @@ class Validation {
  * Checks whether the length of a string is smaller or equal to a maximal length..
  *
  * @param string $check The string to test
- * @param integer $max The maximal string length
- * @return boolean Success
+ * @param int $max The maximal string length
+ * @return bool Success
  */
 	public static function maxLength($check, $max) {
 		return mb_strlen($check) <= $max;
@@ -547,7 +565,7 @@ class Validation {
  *
  * @param string $check Value to check
  * @param string $symbolPosition Where symbol is located (left/right)
- * @return boolean Success
+ * @return bool Success
  */
 	public static function money($check, $symbolPosition = 'left') {
 		$money = '(?!0,?\d)(?:\d{1,3}(?:([, .])\d{3})?(?:\1\d{3})*|(?:\d+))((?!\1)[,.]\d{1,2})?';
@@ -556,7 +574,7 @@ class Validation {
 		} else {
 			$regex = '/^(?!\x{00a2})\p{Sc}?' . $money . '$/u';
 		}
-		return self::_check($check, $regex);
+		return static::_check($check, $regex);
 	}
 
 /**
@@ -570,14 +588,14 @@ class Validation {
  *
  * @param array $check Value to check
  * @param array $options Options for the check.
- * @param boolean $caseInsensitive Set to true for case insensitive comparison.
- * @return boolean Success
+ * @param bool $caseInsensitive Set to true for case insensitive comparison.
+ * @return bool Success
  */
 	public static function multiple($check, $options = array(), $caseInsensitive = false) {
 		$defaults = array('in' => null, 'max' => null, 'min' => null);
 		$options += $defaults;
 
-		$check = array_filter((array)$check);
+		$check = array_filter((array)$check, 'strlen');
 		if (empty($check)) {
 			return false;
 		}
@@ -608,7 +626,7 @@ class Validation {
  * Checks if a value is numeric.
  *
  * @param string $check Value to check
- * @return boolean Success
+ * @return bool Success
  */
 	public static function numeric($check) {
 		return is_numeric($check);
@@ -618,13 +636,13 @@ class Validation {
  * Checks if a value is a natural number.
  *
  * @param string $check Value to check
- * @param boolean $allowZero Set true to allow zero, defaults to false
- * @return boolean Success
+ * @param bool $allowZero Set true to allow zero, defaults to false
+ * @return bool Success
  * @see http://en.wikipedia.org/wiki/Natural_number
  */
 	public static function naturalNumber($check, $allowZero = false) {
 		$regex = $allowZero ? '/^(?:0|[1-9][0-9]*)$/' : '/^[1-9][0-9]*$/';
-		return self::_check($check, $regex);
+		return static::_check($check, $regex);
 	}
 
 /**
@@ -633,13 +651,9 @@ class Validation {
  * @param string|array $check Value to check (string or array)
  * @param string $regex Regular expression to use
  * @param string $country Country code (defaults to 'all')
- * @return boolean Success
+ * @return bool Success
  */
 	public static function phone($check, $regex = null, $country = 'all') {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
-		}
-
 		if ($regex === null) {
 			switch ($country) {
 				case 'us':
@@ -667,9 +681,9 @@ class Validation {
 			}
 		}
 		if (empty($regex)) {
-			return self::_pass('phone', $check, $country);
+			return static::_pass('phone', $check, $country);
 		}
-		return self::_check($check, $regex);
+		return static::_check($check, $regex);
 	}
 
 /**
@@ -678,13 +692,9 @@ class Validation {
  * @param string|array $check Value to check
  * @param string $regex Regular expression to use
  * @param string $country Country to use for formatting
- * @return boolean Success
+ * @return bool Success
  */
 	public static function postal($check, $regex = null, $country = 'us') {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
-		}
-
 		if ($regex === null) {
 			switch ($country) {
 				case 'uk':
@@ -708,9 +718,9 @@ class Validation {
 			}
 		}
 		if (empty($regex)) {
-			return self::_pass('postal', $check, $country);
+			return static::_pass('postal', $check, $country);
 		}
-		return self::_check($check, $regex);
+		return static::_check($check, $regex);
 	}
 
 /**
@@ -719,14 +729,17 @@ class Validation {
  * $check is a legal finite on this platform
  *
  * @param string $check Value to check
- * @param integer $lower Lower limit
- * @param integer $upper Upper limit
- * @return boolean Success
+ * @param int|float $lower Lower limit
+ * @param int|float $upper Upper limit
+ * @return bool Success
  */
 	public static function range($check, $lower = null, $upper = null) {
 		if (!is_numeric($check)) {
 			return false;
 		}
+		if ((float)$check != $check) {
+			return false;
+		}
 		if (isset($lower) && isset($upper)) {
 			return ($check > $lower && $check < $upper);
 		}
@@ -739,13 +752,10 @@ class Validation {
  * @param string|array $check Value to check
  * @param string $regex Regular expression to use
  * @param string $country Country
- * @return boolean Success
+ * @return bool Success
+ * @deprecated Deprecated 2.6. Will be removed in 3.0.
  */
 	public static function ssn($check, $regex = null, $country = null) {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
-		}
-
 		if ($regex === null) {
 			switch ($country) {
 				case 'dk':
@@ -760,9 +770,9 @@ class Validation {
 			}
 		}
 		if (empty($regex)) {
-			return self::_pass('ssn', $check, $country);
+			return static::_pass('ssn', $check, $country);
 		}
-		return self::_check($check, $regex);
+		return static::_check($check, $regex);
 	}
 
 /**
@@ -779,18 +789,18 @@ class Validation {
  * - an optional fragment (anchor tag)
  *
  * @param string $check Value to check
- * @param boolean $strict Require URL to be prefixed by a valid scheme (one of http(s)/ftp(s)/file/news/gopher)
- * @return boolean Success
+ * @param bool $strict Require URL to be prefixed by a valid scheme (one of http(s)/ftp(s)/file/news/gopher)
+ * @return bool Success
  */
 	public static function url($check, $strict = false) {
-		self::_populateIp();
+		static::_populateIp();
 		$validChars = '([' . preg_quote('!"$&\'()*+,-.@_:;=~[]') . '\/0-9\p{L}\p{N}]|(%[0-9a-f]{2}))';
 		$regex = '/^(?:(?:https?|ftps?|sftp|file|news|gopher):\/\/)' . (!empty($strict) ? '' : '?') .
-			'(?:' . self::$_pattern['IPv4'] . '|\[' . self::$_pattern['IPv6'] . '\]|' . self::$_pattern['hostname'] . ')(?::[1-9][0-9]{0,4})?' .
+			'(?:' . static::$_pattern['IPv4'] . '|\[' . static::$_pattern['IPv6'] . '\]|' . static::$_pattern['hostname'] . ')(?::[1-9][0-9]{0,4})?' .
 			'(?:\/?|\/' . $validChars . '*)?' .
 			'(?:\?' . $validChars . '*)?' .
 			'(?:#' . $validChars . '*)?$/iu';
-		return self::_check($check, $regex);
+		return static::_check($check, $regex);
 	}
 
 /**
@@ -798,18 +808,17 @@ class Validation {
  *
  * @param string $check Value to check.
  * @param array $list List to check against.
- * @param boolean $caseInsensitive Set to true for case insensitive comparison.
- * @return boolean Success.
+ * @param bool $caseInsensitive Set to true for case insensitive comparison.
+ * @return bool Success.
  */
 	public static function inList($check, $list, $caseInsensitive = false) {
-		$strict = !is_numeric($check);
-
 		if ($caseInsensitive) {
 			$list = array_map('mb_strtolower', $list);
 			$check = mb_strtolower($check);
+		} else {
+			$list = array_map('strval', $list);
 		}
-
-		return in_array((string)$check, $list, $strict);
+		return in_array((string)$check, $list, true);
 	}
 
 /**
@@ -829,11 +838,11 @@ class Validation {
  * Checks that a value is a valid UUID - http://tools.ietf.org/html/rfc4122
  *
  * @param string $check Value to check
- * @return boolean Success
+ * @return bool Success
  */
 	public static function uuid($check) {
 		$regex = '/^[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[0-5][a-fA-F0-9]{3}-[089aAbB][a-fA-F0-9]{3}-[a-fA-F0-9]{12}$/';
-		return self::_check($check, $regex);
+		return static::_check($check, $regex);
 	}
 
 /**
@@ -865,49 +874,26 @@ class Validation {
  *
  * @param string $check Value to check against the $regex expression
  * @param string $regex Regular expression
- * @return boolean Success of match
+ * @return bool Success of match
  */
 	protected static function _check($check, $regex) {
-		if (is_string($regex) && preg_match($regex, $check)) {
+		if (is_string($regex) && is_scalar($check) && preg_match($regex, $check)) {
 			return true;
 		}
 		return false;
 	}
 
-/**
- * Get the values to use when value sent to validation method is
- * an array.
- *
- * @param array $params Parameters sent to validation method
- * @return void
- */
-	protected static function _defaults($params) {
-		self::_reset();
-		$defaults = array(
-			'check' => null,
-			'regex' => null,
-			'country' => null,
-			'deep' => false,
-			'type' => null
-		);
-		$params += $defaults;
-		if ($params['country'] !== null) {
-			$params['country'] = mb_strtolower($params['country']);
-		}
-		return $params;
-	}
-
 /**
  * Luhn algorithm
  *
- * @param string|array $check
- * @param boolean $deep
- * @return boolean Success
+ * @param string|array $check Value to check.
+ * @param bool $deep If true performs deep check.
+ * @return bool Success
  * @see http://en.wikipedia.org/wiki/Luhn_algorithm
  */
 	public static function luhn($check, $deep = false) {
-		if (is_array($check)) {
-			extract(self::_defaults($check));
+		if (!is_scalar($check)) {
+			return false;
 		}
 		if ($deep !== true) {
 			return true;
@@ -933,9 +919,9 @@ class Validation {
 /**
  * Checks the mime type of a file.
  *
- * @param string|array $check
+ * @param string|array $check Value to check.
  * @param array|string $mimeTypes Array of mime types or regex pattern to check.
- * @return boolean Success
+ * @return bool Success
  * @throws CakeException when mime type can not be determined.
  */
 	public static function mimeType($check, $mimeTypes = array()) {
@@ -951,7 +937,7 @@ class Validation {
 		}
 
 		if (is_string($mimeTypes)) {
-			return self::_check($mime, $mimeTypes);
+			return static::_check($mime, $mimeTypes);
 		}
 
 		foreach ($mimeTypes as $key => $val) {
@@ -963,10 +949,10 @@ class Validation {
 /**
  * Checks the filesize
  *
- * @param string|array $check
- * @param integer|string $size Size in bytes or human readable string like '5MB'
- * @param string $operator See `Validation::comparison()`
- * @return boolean Success
+ * @param string|array $check Value to check.
+ * @param string $operator See `Validation::comparison()`.
+ * @param int|string $size Size in bytes or human readable string like '5MB'.
+ * @return bool Success
  */
 	public static function fileSize($check, $operator = null, $size = null) {
 		if (is_array($check) && isset($check['tmp_name'])) {
@@ -978,31 +964,87 @@ class Validation {
 		}
 		$filesize = filesize($check);
 
-		return self::comparison($filesize, $operator, $size);
+		return static::comparison($filesize, $operator, $size);
 	}
 
 /**
  * Checking for upload errors
  *
- * @param string|array $check
- * @return boolean
+ * @param string|array $check Value to check.
+ * @param bool $allowNoFile Set to true to allow UPLOAD_ERR_NO_FILE as a pass.
+ * @return bool
  * @see http://www.php.net/manual/en/features.file-upload.errors.php
  */
-	public static function uploadError($check) {
+	public static function uploadError($check, $allowNoFile = false) {
 		if (is_array($check) && isset($check['error'])) {
 			$check = $check['error'];
 		}
+		if ($allowNoFile) {
+			return in_array((int)$check, array(UPLOAD_ERR_OK, UPLOAD_ERR_NO_FILE), true);
+		}
 
 		return (int)$check === UPLOAD_ERR_OK;
 	}
 
+/**
+ * Validate an uploaded file.
+ *
+ * Helps join `uploadError`, `fileSize` and `mimeType` into
+ * one higher level validation method.
+ *
+ * ### Options
+ *
+ * - `types` - A list of valid mime types. If empty all types
+ *   will be accepted. The `type` will not be looked at, instead
+ *   the file type will be checked with ext/finfo.
+ * - `minSize` - The minimum file size. Defaults to not checking.
+ * - `maxSize` - The maximum file size. Defaults to not checking.
+ * - `optional` - Whether or not this file is optional. Defaults to false.
+ *   If true a missing file will pass the validator regardless of other constraints.
+ *
+ * @param array $file The uploaded file data from PHP.
+ * @param array $options An array of options for the validation.
+ * @return bool
+ */
+	public static function uploadedFile($file, $options = array()) {
+		$options += array(
+			'minSize' => null,
+			'maxSize' => null,
+			'types' => null,
+			'optional' => false,
+		);
+		if (!is_array($file)) {
+			return false;
+		}
+		$keys = array('name', 'tmp_name', 'error', 'type', 'size');
+		if (array_keys($file) != $keys) {
+			return false;
+		}
+		if (!static::uploadError($file, $options['optional'])) {
+			return false;
+		}
+		if ($options['optional'] && (int)$file['error'] === UPLOAD_ERR_NO_FILE) {
+			return true;
+		}
+		if (isset($options['minSize']) && !static::fileSize($file, '>=', $options['minSize'])) {
+			return false;
+		}
+		if (isset($options['maxSize']) && !static::fileSize($file, '<=', $options['maxSize'])) {
+			return false;
+		}
+		if (isset($options['types']) && !static::mimeType($file, $options['types'])) {
+			return false;
+		}
+		return true;
+	}
+
 /**
  * Lazily populate the IP address patterns used for validations
  *
  * @return void
  */
 	protected static function _populateIp() {
-		if (!isset(self::$_pattern['IPv6'])) {
+		if (!isset(static::$_pattern['IPv6'])) {
 			$pattern = '((([0-9A-Fa-f]{1,4}:){7}(([0-9A-Fa-f]{1,4})|:))|(([0-9A-Fa-f]{1,4}:){6}';
 			$pattern .= '(:|((25[0-5]|2[0-4]\d|[01]?\d{1,2})(\.(25[0-5]|2[0-4]\d|[01]?\d{1,2})){3})';
 			$pattern .= '|(:[0-9A-Fa-f]{1,4})))|(([0-9A-Fa-f]{1,4}:){5}((:((25[0-5]|2[0-4]\d|[01]?\d{1,2})';
@@ -1018,11 +1060,11 @@ class Validation {
 			$pattern .= '\d|[01]?\d{1,2})(\.(25[0-5]|2[0-4]\d|[01]?\d{1,2})){3})?)|((:[0-9A-Fa-f]{1,4})';
 			$pattern .= '{1,2})))|(((25[0-5]|2[0-4]\d|[01]?\d{1,2})(\.(25[0-5]|2[0-4]\d|[01]?\d{1,2})){3})))(%.+)?';
 
-			self::$_pattern['IPv6'] = $pattern;
+			static::$_pattern['IPv6'] = $pattern;
 		}
-		if (!isset(self::$_pattern['IPv4'])) {
+		if (!isset(static::$_pattern['IPv4'])) {
 			$pattern = '(?:(?:25[0-5]|2[0-4][0-9]|(?:(?:1[0-9])?|[1-9]?)[0-9])\.){3}(?:25[0-5]|2[0-4][0-9]|(?:(?:1[0-9])?|[1-9]?)[0-9])';
-			self::$_pattern['IPv4'] = $pattern;
+			static::$_pattern['IPv4'] = $pattern;
 		}
 	}
 
@@ -1032,7 +1074,7 @@ class Validation {
  * @return void
  */
 	protected static function _reset() {
-		self::$errors = array();
+		static::$errors = array();
 	}
 
 }
