@@ -144,7 +144,7 @@ $SLANG = array(
     'BadLabelY'             => 'La coordenada de la etiqueta Y debe ser un entero de cero o más',
     'BadMaxFPS'             => 'MPS máximos debe tener un valor entero positivo o de punto flotante',
     'BadMotionFrameSkip'    => 'Motion Frame skip count must be an integer of zero or more',
-    'BadNameChars'          => 'Los nombre sólo pueden contener carácteres alfanuméricos además de guiones y guiones bajos',
+    'BadNameChars'          => 'Los nombre sólo pueden contener carácteres alfanuméricos, espacios además de guiones y guiones bajos',
     'BadPalette'            => 'La paleta debe tener un valor válido',
     'BadPath'               => 'La ruta debe tener un valo válido',
     'BadPort'               => 'El puerto debe ser un número válido',
@@ -794,14 +794,14 @@ function zmVlang( $langVarArray, $count )
 
 $OLANG = array(
 	'OPTIONS_FFMPEG' => array(
-		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		'Help' => "Parameters in this field are passed on to FFmpeg. Multiple parameters can be separated by ,~~ ".
 		          "Examples (do not enter quotes)~~~~".
 		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
 		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
-		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+		          "\"loglevel=debug\" Set verbosity of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
 	),
 	'OPTIONS_LIBVLC' => array(
-		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		'Help' => "Parameters in this field are passed on to libVLC. Multiple parameters can be separated by ,~~ ".
 		          "Examples (do not enter quotes)~~~~".
 		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
 		          "\"--verbose=2\" Set verbosity of libVLC"
