@@ -144,7 +144,7 @@ $SLANG = array(
     'BadLabelY'            => 'Label Y co-ordinate moet een nummer nul of groter zijn',
     'BadMaxFPS'            => 'Maximum FPS moet een positieve integer of floating point waarde zijn',
     'BadMotionFrameSkip'   => 'Motion Frame skip count must be an integer of zero or more',
-    'BadNameChars'         => 'Namen mogen alleen alpha numerieke karakters bevatten plus hyphens en underscores',
+    'BadNameChars'         => 'Namen mogen alleen alpha numerieke karakters, ruimten bevatten plus hyphens en underscores',
     'BadPalette'           => 'Palette moet een geldige waarde zijn', // Added - 2009-03-31
     'BadPath'              => 'Pad  moet een geldige waarde zijn',
     'BadPort'              => 'Port moet een geldige nummer zijn',
@@ -886,14 +886,14 @@ function zmVlang( $langVarArray, $count )
 // So for example, to override the help text for ZM_LANG_DEFAULT do
 $OLANG = array(
 	'OPTIONS_FFMPEG' => array(
-		'Help' => "Parameters in this field are passwd on to FFmpeg. Multiple parameters can be separated by ,~~ ".
+		'Help' => "Parameters in this field are passed on to FFmpeg. Multiple parameters can be separated by ,~~ ".
 		          "Examples (do not enter quotes)~~~~".
 		          "\"allowed_media_types=video\" Set datatype to request fromcam (audio, video, data)~~~~".
 		          "\"reorder_queue_size=nnn\" Set number of packets to buffer for handling of reordered packets~~~~".
-		          "\"loglevel=debug\" Set verbosiy of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
+		          "\"loglevel=debug\" Set verbosity of FFmpeg (quiet, panic, fatal, error, warning, info, verbose, debug)"
 	),
 	'OPTIONS_LIBVLC' => array(
-		'Help' => "Parameters in this field are passwd on to libVLC. Multiple parameters can be separated by ,~~ ".
+		'Help' => "Parameters in this field are passed on to libVLC. Multiple parameters can be separated by ,~~ ".
 		          "Examples (do not enter quotes)~~~~".
 		          "\"--rtp-client-port=nnn\" Set local port to use for rtp data~~~~". 
 		          "\"--verbose=2\" Set verbosity of libVLC"
